@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2008 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 /* This module contains debugging functions. */
 
@@ -49,7 +49,7 @@ Returns:      nothing
 */
 
 void
-debug_print_string(uschar *s, int len, char *post)
+debug_print_string(uschar *s, int len, const char *post)
 {
 for (; len-- > 0; s++)
   {
@@ -365,7 +365,7 @@ Returns:     nothing
 */
 
 void
-debug_print_para(item *item_list, item *last_item, char *when)
+debug_print_para(item *item_list, item *last_item, const char *when)
 {
 item *i;
 int pagenumber = 0;
