@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011, 2012, 2013 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 /* Error handling routines */
 
@@ -65,7 +65,7 @@ static error_struct error_data[] = {
 /* 25-29 */
 { ec_warning,  "line overflow (%spt)" },
 { ec_warning,  "internal error: page %d is too long: new page started" },
-{ ec_disaster, "error loading metric data for font '%s': %s" },
+{ ec_disaster, "error loading metric data for font \"%s\": %s%s" },
 { ec_disaster, "internal error: special auxiliary font missing" },
 { ec_disaster, "internal error: substitute character not found" },
 /* 30-34 */
