@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 /* This module contains functions related to fonts. */
 
@@ -198,7 +198,10 @@ for (;;)
     (void)error(27, filename, "unrecognized metric data line: ", line); /* Hard */
 
   pp = line + 2;
-  while (memcmp(pp, "WX", 2) != 0) pp++;
+
+  while (*pp != 0 && memcmp(pp, "WX", 2) != 0) pp++;
+  if (*pp == 0)
+    (void)error(27, filename, "unrecognized metric data line: ", line); /* Hard */
   pp = read_number(&width, pp+2);
 
   /* If this is a StandardEncoding font, scan the list of characters so as to
@@ -207,7 +210,9 @@ for (;;)
   if (af->stdencoding)
     {
     uschar *cname;
-    while (memcmp(pp, "N ", 2) != 0) pp++;
+    while (*pp != 0 && memcmp(pp, "N ", 2) != 0) pp++;
+    if (*pp == 0)
+      (void)error(27, filename, "unrecognized metric data line: ", line); /* Hard */
     cname = (pp += 2);
     while (*pp != ' ') pp++;
     *pp = 0;
@@ -274,7 +279,7 @@ while (kerncount--)
   int b = -1;
 
   if (Ufgets(line, sizeof(line), f) == NULL)
-    (void)error(27, filename, "unexpected end of kerning data");  /* Hard */
+    (void)error(27, filename, "unexpected end of kerning data", "");  /* Hard */
   if (memcmp(line, "EndKernPairs", 12) == 0) break;
 
   /* Skip blank lines */
@@ -594,7 +599,7 @@ afontstr *af = vf->afont;
 
 if (lastc < 0 || lastc > 0xffff || c > 0xffff) return 0;
 
-pair = (lastc << 16) | c;
+pair = ((unsigned int)lastc << 16) | (unsigned int)c;
 
 bot = 0;
 top = af->kerncount;
