@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 /* This header defines all the global functions, except the ucp and hyphenation
 ones. */
@@ -26,8 +26,8 @@ extern void          debug_printf(const char *, ...) PRINTF_FUNCTION ;
 extern void          debug_printfixed(int, const char *);
 extern void          debug_print_item_list(item *, const char *);
 extern void          debug_print_line_text(outputline *);
-extern void          debug_print_para(item *, item *, char *v);
-extern void          debug_print_string(uschar *, int, char *);
+extern void          debug_print_para(item *, item *, const char *);
+extern void          debug_print_string(uschar *, int, const char *);
 
 extern BOOL          entity_expand(item *);
 extern uschar       *entity_find(uschar *, uschar **, BOOL, uschar *);
