@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 /* This module contains code for creating one or more indexes. */
 
@@ -522,7 +522,7 @@ index number, the page number, and a text string for sorting. */
 for (i = item_list; i != NULL && i != index_item; i = i->next)
   {
   indexstr *ix;
-  int bp;
+  unsigned int bp;
   BOOL hassee;
 
   if (Ustrcmp(i->name, "#FILENAME") == 0)
@@ -608,7 +608,7 @@ for (i = item_list; i != NULL && i != index_item; i = i->next)
           {
           unsigned int *ip;
           int length = 1;
-          int c = GETCHARLEN(c, tp, length);
+          unsigned int c = GETCHARLEN(c, tp, length);
           for (ip = index_sort_omit;; ip++)
             {
             if (c == *ip) break;      /* Skip this character */
