@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 /* This module contains a number of miscellaneous small utility functions. */
 
@@ -669,7 +669,7 @@ Arguments:
 Returns:     number of characters placed in the buffer
 */
 
-static char *alphabet = "abcdefghijklmnopqrstuvwxyz";
+static const char *alphabet = "abcdefghijklmnopqrstuvwxyz";
 
 int
 misc_alpha(uschar *s, int n)
