@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2008, 2011 */
+/* Copyright (c) Philip Hazel, 2008, 2011, 2013 */
 
 /* This module contains functions for doing things to pages. */
 
@@ -190,7 +190,11 @@ item *j, *k, *fpushed, *lpushed;
 item *tgroup = NULL;
 item *tbody = NULL;
 item *tfoot = NULL;
-item *thead = NULL;
+
+/* This variable is commented because its value is not currently used, and
+compilers complain. */
+
+/* item *thead = NULL; */
 
 /* Look for a title, and find its depth */
 
@@ -227,7 +231,7 @@ for (j = ip->next; j != ip->partner; j = j->next)
 
   else if (Ustrcmp(j->name, "thead") == 0)
     {
-    thead = j;
+    /* thead = j;  not currently used */
     inhead = TRUE;
     }
 
