@@ -2,22 +2,22 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011 */
+/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
 
 /* This module contains functions for handling "processing instructions". */
 
 #include "sdop.h"
 
-enum { PI_STRING, PI_STRING_LIST, PI_YESNO, PI_INTEGER, PI_FP, PI_DIMENSION,
-       PI_SDIMENSION, PI_DIMOROBJ, PI_FONT, PI_FULLFONT, PI_FULLFONT4,
-       PI_FULLFONT8, PI_ALIGN, PI_COLOUR, PI_INDENT };
+enum { PI_STRING, PI_TOC_LINE_STRING_LIST, PI_YESNO, PI_INTEGER, PI_FP,
+       PI_DIMENSION, PI_SDIMENSION, PI_DIMOROBJ, PI_FONT, PI_FULLFONT,
+       PI_FULLFONT4, PI_FULLFONT8, PI_ALIGN, PI_COLOUR, PI_INDENT };
 
 typedef struct piparam {
-  uschar *name;            /* parameter name */
-  BOOL   *orptr;           /* pointer to command line override switch */
-  void   *pointer;         /* pointer to data variable */
-  int     type;            /* type of data variable */
-  int     num;             /* number of elements if a list */
+  uschar     *name;         /* parameter name */
+  BOOL       *orptr;        /* pointer to command line override switch */
+  void       *pointer;      /* pointer to data variable */
+  short int   type;         /* type of data variable */
+  short int   obsolete;     /* non-zero if deprecated; relative index of new option */
 } piparam;
 
 /* Header/footer data for preface and body. These are checked when pages are
@@ -50,7 +50,7 @@ static piparam hfparam_list[] = {
   { US"preface_head_right_recto",  NULL, &(preface_headfoot.head_right_recto),  PI_STRING, 0 },
   { US"preface_head_right_verso",  NULL, &(preface_headfoot.head_right_verso),  PI_STRING, 0 },
 
-  { US"chapter_skip_head", NULL, &chapter_skip_head, PI_YESNO }
+  { US"chapter_skip_head", NULL, &chapter_skip_head, PI_YESNO, 0 }
 };
 
 static int hfparam_list_count = sizeof(hfparam_list)/sizeof(piparam);
@@ -67,7 +67,7 @@ static int mcparam_list_count = sizeof(mcparam_list)/sizeof(piparam);
 /* Things that change while creating pages */
 
 static piparam cpparam_list[] = {
-  { US"index_headings",         NULL, &index_headings_enabled, PI_YESNO, 0 }
+  { US"index_headings",  NULL, &index_headings_enabled, PI_YESNO, 0 }
 };
 
 static int cpparam_list_count = sizeof(cpparam_list)/sizeof(piparam);
@@ -75,11 +75,17 @@ static int cpparam_list_count = sizeof(cpparam_list)/sizeof(piparam);
 /* Itemized and ordered list parameters */
 
 static piparam list_param_list[] = {
-  { US"ilist_font",           NULL, &ilist_fs,            PI_FONT, 0 },
-  { US"olist_font",           NULL, &olist_fs,            PI_FONT, 0 },
-  { US"olist_format",         NULL, &olist_format,        PI_STRING, 0 },
-/* This was inconsistently used; keep for compatibility. */
-  { US"orderedlist_format",   NULL, &olist_format,        PI_STRING, 0 }
+  { US"font_ilist_tag",      NULL, &ilist_tag_vfont,        PI_FULLFONT, 0 },
+  { US"font_olist_tag",      NULL, &olist_tag_vfont,        PI_FULLFONT, 0 },
+  { US"ilist_font",          NULL, &(ilist_tag_vfont.type), PI_FONT,     2 },
+  { US"ilist_tag_rgb",       NULL, &ilist_tag_colour[0],    PI_COLOUR,   0 },
+  { US"ilist_tag_style",     NULL, &(ilist_tag_vfont.type), PI_FONT,     0 },
+  { US"olist_font",          NULL, &(olist_tag_vfont.type), PI_FONT,     4 },
+  { US"olist_format",        NULL, &olist_format,           PI_STRING,   1 },
+  { US"olist_tag_format",    NULL, &olist_format,           PI_STRING,   0 },
+  { US"olist_tag_rgb",       NULL, &olist_tag_colour[0],    PI_COLOUR,   0 },
+  { US"olist_tag_style",     NULL, &(olist_tag_vfont.type), PI_FONT,     0 },
+  { US"orderedlist_format",  NULL, &olist_format,           PI_STRING,  -3 }
 };
 
 static int list_param_list_count = sizeof(list_param_list)/sizeof(piparam);
@@ -87,12 +93,12 @@ static int list_param_list_count = sizeof(list_param_list)/sizeof(piparam);
 /* Figure, example, and table title format parameters */
 
 static piparam figtabparam_list[] = {
-  { US"example_number_format",    NULL, &example_number_format,            PI_STRING,      0 },
-  { US"example_title_format",     NULL, &example_title_format,             PI_STRING,      0 },
-  { US"figure_number_format",     NULL, &figure_number_format,             PI_STRING,      0 },
-  { US"figure_title_format",      NULL, &figure_title_format,              PI_STRING,      0 },
-  { US"table_number_format",      NULL, &table_number_format,              PI_STRING,      0 },
-  { US"table_title_format",       NULL, &table_title_format,               PI_STRING,      0 }
+  { US"example_number_format",  NULL, &example_number_format,  PI_STRING,  0 },
+  { US"example_title_format",   NULL, &example_title_format,   PI_STRING,  0 },
+  { US"figure_number_format",   NULL, &figure_number_format,   PI_STRING,  0 },
+  { US"figure_title_format",    NULL, &figure_title_format,    PI_STRING,  0 },
+  { US"table_number_format",    NULL, &table_number_format,    PI_STRING,  0 },
+  { US"table_title_format",     NULL, &table_title_format,     PI_STRING,  0 }
 };
 
 static int figtabparam_list_count = sizeof(figtabparam_list)/sizeof(piparam);
@@ -100,10 +106,10 @@ static int figtabparam_list_count = sizeof(figtabparam_list)/sizeof(piparam);
 /* Figure and example title layout paramters */
 
 static piparam figexlayoutparam_list[] = {
-  { US"example_title_justify",    NULL, &example_title_justify,            PI_ALIGN,       0 },
-  { US"example_title_width",      NULL, &example_title_width,              PI_DIMOROBJ,    0 },
-  { US"figure_title_justify",     NULL, &figure_title_justify,             PI_ALIGN,       0 },
-  { US"figure_title_width",       NULL, &figure_title_width,               PI_DIMOROBJ,    0 }
+  { US"example_title_justify",  NULL, &example_title_justify,  PI_ALIGN,    0 },
+  { US"example_title_width",    NULL, &example_title_width,    PI_DIMOROBJ, 0 },
+  { US"figure_title_justify",   NULL, &figure_title_justify,   PI_ALIGN,    0 },
+  { US"figure_title_width",     NULL, &figure_title_width,     PI_DIMOROBJ, 0 }
 };
 
 static int figexlayoutparam_list_count = sizeof(figexlayoutparam_list)/sizeof(piparam);
@@ -111,9 +117,9 @@ static int figexlayoutparam_list_count = sizeof(figexlayoutparam_list)/sizeof(pi
 /* Table title layout parameters */
 
 static piparam tablelayoutparam_list[] = {
-  { US"table_indent",             NULL, &table_overall_indent,             PI_DIMENSION,   0 },
-  { US"table_title_justify",      NULL, &table_title_justify,              PI_ALIGN,       0 },
-  { US"table_title_width",        NULL, &table_title_width,                PI_DIMOROBJ,    0 }
+  { US"table_indent",           NULL, &table_overall_indent,   PI_DIMENSION, 0 },
+  { US"table_title_justify",    NULL, &table_title_justify,    PI_ALIGN,     0 },
+  { US"table_title_width",      NULL, &table_title_width,      PI_DIMOROBJ,  0 }
 };
 
 static int tablelayoutparam_list_count = sizeof(tablelayoutparam_list)/sizeof(piparam);
@@ -121,23 +127,24 @@ static int tablelayoutparam_list_count = sizeof(tablelayoutparam_list)/sizeof(pi
 /* General layout parameters that apply throughout the document. */
 
 static piparam layparm_list[] = {
-  { US"blockquote_indent",        NULL, &blockquote_layparm,               PI_INDENT,      0 },
-  { US"blockquote_ruled",         NULL, &blockquote_ruled,                 PI_YESNO,       0 },
-  { US"blockquote_title_justify", NULL, &blockquote_title_justify,         PI_ALIGN,       0 },
-  { US"formalpara_indent",        NULL, &formalpara_layparm,               PI_INDENT,      0 },
-  { US"ilist_indent",             NULL, &ilistpara_layparm,                PI_INDENT,      0 },
-  { US"literal_indent",           NULL, &literalpara_layparm,              PI_INDENT,      0 },
-  { US"note_indent",              NULL, &note_layparm,                     PI_INDENT,      0 },
-  { US"note_ruled",               NULL, &note_ruled,                       PI_YESNO,       0 },
-  { US"note_title_justify",       NULL, &note_title_justify,               PI_ALIGN,       0 },
-  { US"olist_indent",             NULL, &olistpara_layparm,                PI_INDENT,      0 },
-  { US"para_indent",              NULL, &para_layparm,                     PI_INDENT,      0 },
-  { US"sidebar_indent",           NULL, &sidebar_layparm,                  PI_INDENT,      0 },
-  { US"sidebar_ruled",            NULL, &sidebar_ruled,                    PI_YESNO,       0 },
-  { US"sidebar_title_justify",    NULL, &sidebar_title_justify,            PI_ALIGN,       0 },
-  { US"term_indent",              NULL, &term_layparm,                     PI_INDENT,      0 },
-  { US"vlist_indent",             NULL, &vlistpara_layparm,                PI_INDENT,      0 },
-  { US"vlist_title_indent",       NULL, &vlisttitle_layparm,               PI_INDENT,      0 }
+  { US"blockquote_indent",        NULL, &blockquote_layparm,       PI_INDENT, 0 },
+  { US"blockquote_ruled",         NULL, &blockquote_ruled,         PI_YESNO,  0 },
+  { US"blockquote_title_justify", NULL, &blockquote_title_justify, PI_ALIGN,  0 },
+  { US"formalpara_indent",        NULL, &formalpara_layparm,       PI_INDENT, 0 },
+  { US"ilist_indent",             NULL, &ilistpara_layparm,        PI_INDENT, 0 },
+  { US"literal_indent",           NULL, &literalpara_layparm,      PI_INDENT, 0 },
+  { US"note_indent",              NULL, &note_layparm,             PI_INDENT, 0 },
+  { US"note_ruled",               NULL, &note_ruled,               PI_YESNO,  0 },
+  { US"note_title_justify",       NULL, &note_title_justify,       PI_ALIGN,  0 },
+  { US"olist_indent",             NULL, &olistpara_layparm,        PI_INDENT, 0 },
+  { US"para_indent",              NULL, &para_layparm,             PI_INDENT, 0 },
+  { US"sidebar_indent",           NULL, &sidebar_layparm,          PI_INDENT, 0 },
+  { US"sidebar_ruled",            NULL, &sidebar_ruled,            PI_YESNO,  0 },
+  { US"sidebar_title_justify",    NULL, &sidebar_title_justify,    PI_ALIGN,  0 },
+  { US"term_indent",              NULL, &term_layparm,             PI_INDENT, 2 },
+  { US"vlist_indent",             NULL, &vlistpara_layparm,        PI_INDENT, 0 },
+  { US"vlist_term_indent",        NULL, &term_layparm,             PI_INDENT, 0 },
+  { US"vlist_title_indent",       NULL, &vlisttitle_layparm,       PI_INDENT, 0 }
 };
 
 static int layparm_list_count = sizeof(layparm_list)/sizeof(piparam);
@@ -173,7 +180,8 @@ and cannot vary for different parts of the document. */
 
 static piparam glparam_list[] = {
   { US"background_rgb",           NULL, &background_colour[0],             PI_COLOUR,      0 },
-  { US"command_font",             NULL, &command_fs,                       PI_FONT,        0 },
+  { US"command_font",             NULL, &command_fs,                       PI_FONT,        1 },
+  { US"command_style",            NULL, &command_fs,                       PI_FONT,        0 },
   { US"font_blockquote_title",    NULL, &blockquote_title_vfont,           PI_FULLFONT,    0 },
   { US"font_booktitle1",          NULL, &booktitle1_vfont,                 PI_FULLFONT,    0 },
   { US"font_booktitle2",          NULL, &booktitle2_vfont,                 PI_FULLFONT,    0 },
@@ -207,7 +215,8 @@ static piparam glparam_list[] = {
   { US"font_toc_fill",            NULL, &toc_fill_vfont,                   PI_FULLFONT,    0 },
   { US"font_tocmono",             NULL, &toc_vfonttable,                   PI_FULLFONT4,   0 },
   { US"foot_length",              NULL, &page_foot_length,                 PI_DIMENSION,   0 },
-  { US"function_font",            NULL, &function_fs,                      PI_FONT,        0 },
+  { US"function_font",            NULL, &function_fs,                      PI_FONT,        1 },
+  { US"function_style",           NULL, &function_fs,                      PI_FONT,        0 },
   { US"head_length",              NULL, &page_head_length,                 PI_DIMENSION,   0 },
   { US"index_sort_omit",          NULL, &index_sort_omit_string,           PI_STRING,      0 },
   { US"literal_indent_fudge",     NULL, &literal_indent_fudge,             PI_YESNO,       0 },
@@ -216,13 +225,15 @@ static piparam glparam_list[] = {
   { US"margin_left_recto",        NULL, &margin_left_recto,                PI_DIMENSION,   0 },
   { US"margin_left_verso",        NULL, &margin_left_verso,                PI_DIMENSION,   0 },
   { US"monospace_family",         NULL, &(type_families[2]),               PI_STRING,      0 },
-  { US"option_font",              NULL, &option_fs,                        PI_FONT,        0 },
+  { US"option_font",              NULL, &option_fs,                        PI_FONT,        1 },
+  { US"option_style",             NULL, &option_fs,                        PI_FONT,        0 },
   { US"page_foot_line_width",     NULL, &page_foot_linewidth,              PI_DIMENSION,   0 },
   { US"page_full_length",         NULL, &page_full_length,                 PI_DIMENSION,   0 },
   { US"page_head_line_width",     NULL, &page_head_linewidth,              PI_DIMENSION,   0 },
   { US"page_line_width",          NULL, &page_linewidth,                   PI_DIMENSION,   0 },
   { US"paper_size",               NULL, &paper_size,                       PI_STRING,      0 },
-  { US"replaceable_font",         NULL, &replaceable_fs,                   PI_FONT,        9 },
+  { US"replaceable_font",         NULL, &replaceable_fs,                   PI_FONT,        1 },
+  { US"replaceable_style",        NULL, &replaceable_fs,                   PI_FONT,        0 },
   { US"sanserif_family",          NULL, &(type_families[1]),               PI_STRING,      0 },
   { US"scale_typesize_base",      NULL, &scale_typesize_base,              PI_FP,          0 },
   { US"serif_family",             NULL, &(type_families[0]),               PI_STRING,      0 },
@@ -242,12 +253,14 @@ static piparam glparam_list[] = {
   { US"toc_head_left_verso",      NULL, &(toc_headfoot.head_left_verso),   PI_STRING,      0 },
   { US"toc_head_right_recto",     NULL, &(toc_headfoot.head_right_recto),  PI_STRING,      0 },
   { US"toc_head_right_verso",     NULL, &(toc_headfoot.head_right_verso),  PI_STRING,      0 },
-  { US"toc_line_chapter_strings", NULL, toc_line_chapter_strings,          PI_STRING_LIST, 6 },
-  { US"toc_line_sect1_strings",   NULL, toc_line_sect1_strings,            PI_STRING_LIST, 6 },
-  { US"toc_line_sect2_strings",   NULL, toc_line_sect2_strings,            PI_STRING_LIST, 6 },
+  { US"toc_line_chapter_strings", NULL, toc_line_chapter_strings,          PI_TOC_LINE_STRING_LIST, 0 },
+  { US"toc_line_sect1_strings",   NULL, toc_line_sect1_strings,            PI_TOC_LINE_STRING_LIST, 0 },
+  { US"toc_line_sect2_strings",   NULL, toc_line_sect2_strings,            PI_TOC_LINE_STRING_LIST, 0 },
   { US"toc_title",                NULL, &toc_title,                        PI_STRING,      0 },
-  { US"userinput_font",           NULL, &userinput_fs,                     PI_FONT,        9 },
-  { US"varname_font",             NULL, &varname_fs,                       PI_FONT,        9 },
+  { US"userinput_font",           NULL, &userinput_fs,                     PI_FONT,        1 },
+  { US"userinput_style",          NULL, &userinput_fs,                     PI_FONT,        0 },
+  { US"varname_font",             NULL, &varname_fs,                       PI_FONT,        1 },
+  { US"varname_style",            NULL, &varname_fs,                       PI_FONT,        0 },
   { US"warn_unsupported",         &warn_unsupported_set,
                                         &warn_unsupported,                 PI_YESNO,       0 },
   { US"warn_unsupported_characters", &warn_unsupported_chars_set,
@@ -330,7 +343,10 @@ static int pftype_list_count = sizeof(pftype_list)/sizeof(pftype);
 
 /* A font string is of the form "<size>,<leading>,<family>,<type>". For example
 "14,2,serif,bold". All items can be omitted. The value -1 is returned for those
-that are not given.
+that are not given. When this is used for global settings, font sizes are not
+scaled, as the final scaling is applied to all globals fonts after the globals
+have been processed. However local font size settings must be scaled. This is
+handled by the "scale" argument.
 
 Arguments:
   s             the string
@@ -338,13 +354,15 @@ Arguments:
   pleading      where to put the leading
   pfamily       where to put the family
   ptype         where to put the type
+  scale         TRUE if font sizes are to be scaled
 
 Returns:        TRUE if no problem
                 FALSE if an error has been generated
 */
 
 static BOOL
-parse_font(uschar *s, int *psize, int *pleading, int *pfamily, int *ptype)
+parse_font(uschar *s, int *psize, int *pleading, int *pfamily, int *ptype,
+  BOOL scale)
 {
 int k;
 
@@ -357,9 +375,18 @@ for (k = 0; k < 2; k++)
   if (*s != ',')
     {
     if (k == 0)
+      {
       *psize = misc_get_fp(s, &s);
+      if (scale)
+        *psize = MULDIV(*psize, scale_typesize_base, scale_typesize_base_orig);
+      }
     else
+      {
       *pleading = misc_get_fp(s, &s);
+      if (scale)
+        *pleading = MULDIV(*pleading, scale_typesize_base,
+          scale_typesize_base_orig);
+      }
     }
   if (*s != 0 && *s++ != ',') return error(91);
   }
@@ -416,12 +443,14 @@ Arguments:
   i          the ?sdop element
   pilist     the list to scan
   count      the length of the list
+  scale      TRUE if font sizes are to be scaled
+  warnobs    TRUE if warnings for obsolete parameters are wanted
 
 Returns:     nothing
 */
 
 static void
-check_pin_list(item *i, piparam *pilist, int count)
+check_pin_list(item *i, piparam *pilist, int count, BOOL scale, BOOL warnobs)
 {
 int j, k, x;
 uschar *s;
@@ -431,6 +460,11 @@ for (j = 0; j < count; j++)
   int typesize, typeleading, typefamily, typetype;
   paramstr *p = misc_param_find(i, pilist[j].name);
 
+  /* Warn for deprecated processing elements */
+
+  if (warnobs && p != NULL && pilist[j].obsolete != 0)
+    (void)error(115, pilist[j].name, pilist[j+pilist[j].obsolete].name);
+
   if (p == NULL ||                   /* Parameter not set here, or */
       (pilist[j].orptr != NULL &&    /* there's a command line override and */
         *(pilist[j].orptr)))         /* it is set. */
@@ -457,7 +491,7 @@ for (j = 0; j < count; j++)
 
     case PI_FULLFONT:
     if (parse_font(p->value, &typesize, &typeleading, &typefamily,
-        &typetype))
+        &typetype, scale))
       {
       vfontstr *v = (vfontstr *)(pilist[j].pointer);
       if (typesize > 0) v->size = typesize;
@@ -470,7 +504,7 @@ for (j = 0; j < count; j++)
     case PI_FULLFONT4:
     case PI_FULLFONT8:
     if (parse_font(p->value, &typesize, &typeleading, &typefamily,
-        &typetype))
+        &typetype, scale))
       {
       vfontstr **vv;
       int fontcount = (pilist[j].type == PI_FULLFONT4)? 4 : 8;
@@ -553,11 +587,11 @@ for (j = 0; j < count; j++)
     DEBUG(D_param) debug_printf("%s=\"%s\"\n", pilist[j].name, p->value);
     break;
 
-    case PI_STRING_LIST:
+    case PI_TOC_LINE_STRING_LIST:
       {
       uschar **lp = (uschar **)(pilist[j].pointer);
       s = p->value;
-      for (k = 0; k < pilist[j].num; k++)
+      for (k = 0; k < TOC_LINE_STRING_COUNT; k++)
         {
         uschar *t;
         for (t = s; *t != 0 && *t != ','; t++)
@@ -573,7 +607,7 @@ for (j = 0; j < count; j++)
           debug_printf("%s[%d]=\"%s\"\n", pilist[j].name, k, lp[k]);
         if (*s == ',') s++;
         }
-      if (*s != 0) error(52, p->value, pilist[j].num);
+      if (*s != 0) error(52, p->value, TOC_LINE_STRING_COUNT);
       }
     break;
 
@@ -708,7 +742,7 @@ Returns:    nothing
 void
 pin_change_layparm(item *i)
 {
-check_pin_list(i, layparm_list, layparm_list_count);
+check_pin_list(i, layparm_list, layparm_list_count, FALSE, TRUE);
 
 /* Some indents need copying into alternate blocks (which are typically used so
 they can have different spacing settings). */
@@ -734,7 +768,7 @@ Returns:    nothing
 void
 pin_change_font_assign(item *i)
 {
-check_pin_list(i, subsupparam_list, subsupparam_list_count);
+check_pin_list(i, subsupparam_list, subsupparam_list_count, FALSE, TRUE);
 }
 
 
@@ -753,7 +787,7 @@ Returns:    nothing
 void
 pin_change_columns(item *i)
 {
-check_pin_list(i, mcparam_list, mcparam_list_count);
+check_pin_list(i, mcparam_list, mcparam_list_count, FALSE, TRUE);
 }
 
 
@@ -771,7 +805,7 @@ Returns:    nothing
 void
 pin_dynamic_layparm(item *i)
 {
-check_pin_list(i, dynamic_layparm_list, dynamic_layparm_list_count);
+check_pin_list(i, dynamic_layparm_list, dynamic_layparm_list_count, FALSE, TRUE);
 }
 
 
@@ -790,7 +824,7 @@ Returns:    nothing
 void
 pin_dynamic_subsuper(item *i)
 {
-check_pin_list(i, subsuplevel_list, subsuplevel_list_count);
+check_pin_list(i, subsuplevel_list, subsuplevel_list_count, FALSE, TRUE);
 if (subscript_down > 127)
   {
   subscript_down = 127;
@@ -820,7 +854,7 @@ Returns:    nothing
 void
 pin_paging_changes(item *i)
 {
-check_pin_list(i, cpparam_list, cpparam_list_count);
+check_pin_list(i, cpparam_list, cpparam_list_count, FALSE, TRUE);
 }
 
 
@@ -842,7 +876,7 @@ pin_figtab_format_changes(item *i)
 {
 uschar *oldfnf = figure_number_format;
 uschar *oldtnf = table_number_format;
-check_pin_list(i, figtabparam_list, figtabparam_list_count);
+check_pin_list(i, figtabparam_list, figtabparam_list_count, FALSE, TRUE);
 if (figure_number_format != oldfnf)
   {
   uschar *p;
@@ -872,7 +906,7 @@ if (example_number_format != oldtnf)
 void
 pin_figex_layout_changes(item *i)
 {
-check_pin_list(i, figexlayoutparam_list, figexlayoutparam_list_count);
+check_pin_list(i, figexlayoutparam_list, figexlayoutparam_list_count, FALSE, TRUE);
 }
 
 
@@ -881,7 +915,7 @@ check_pin_list(i, figexlayoutparam_list, figexlayoutparam_list_count);
 void
 pin_table_layout_changes(item *i)
 {
-check_pin_list(i, tablelayoutparam_list, tablelayoutparam_list_count);
+check_pin_list(i, tablelayoutparam_list, tablelayoutparam_list_count, FALSE, TRUE);
 }
 
 
@@ -902,7 +936,7 @@ Returns:    nothing
 void
 pin_headfoot(item *i)
 {
-check_pin_list(i, hfparam_list, hfparam_list_count);
+check_pin_list(i, hfparam_list, hfparam_list_count, FALSE, TRUE);
 }
 
 
@@ -921,35 +955,48 @@ Returns:     nothing
 void
 pin_default_list_params(void)
 {
-ilist_fs = FS_ROMAN;
-olist_fs = FS_ROMAN;
+int i;
+ilist_tag_vfont = maintext_vfont;
+olist_tag_vfont = maintext_vfont;
 olist_format = US"(%s)";
+for (i = 0; i < 3; i++)
+  {
+  ilist_tag_colour[i] = 0;
+  olist_tag_colour[i] = 0;
+  }
 }
 
 
 
 /*************************************************
-*         Change ordered list parameters         *
+*    Change itemized/ordered list parameters     *
 *************************************************/
 
-/* This function is called for each ?sdop item in a page as it is being
-printed. It processes changes to itemized and ordered list parameters. If there
-is a change to the ordered list numbering format, the new string is passed
-through entity_find().
+/* This function is called for each ?sdop item in a page during font assignment
+and also as it is being printed. It processes changes to itemized and ordered
+list parameters. If the size or leading of the ilist or olist tag fonts is
+changed, we must apply the overall scaling by passing TRUE as the second-last
+argument of check_pin_list().  Also, if there is a change to the ordered list
+numbering format, the new string is passed through entity_find().
+
+Arguments:  i        the ?sdop item
+            warnobs  TRUE to warn for obsolete parameters
 
-Argument:   the ?sdop item
 Returns:    nothing
 */
 
 void
-pin_change_list_params(item *i)
+pin_change_list_params(item *i, BOOL warnobs)
 {
 BOOL found;
 int length;
 uschar *p, *pp, *np, *value;
 uschar *old_olist_format = olist_format;
 
-check_pin_list(i, list_param_list, list_param_list_count);
+check_pin_list(i, list_param_list, list_param_list_count, TRUE, warnobs);
+
+/* Handle changes to the olist format. */
+
 if (olist_format == old_olist_format) return;
 
 length = 1;
@@ -1016,7 +1063,6 @@ BOOL
 pin_global(item *item_list)
 {
 item *i;
-int orig_scale_typesize_base = scale_typesize_base;
 
 DEBUG(D_any) debug_printf("Setting global parameters\n");
 
@@ -1024,7 +1070,7 @@ for (i = item_list; i != NULL; i = i->next)
   {
   if (Ustrcmp(i->name, US"?sdop") != 0) continue;
   read_linenumber = i->linenumber;
-  check_pin_list(i, glparam_list, glparam_list_count);
+  check_pin_list(i, glparam_list, glparam_list_count, FALSE, TRUE);
   (void)misc_yesno_vector(i, US"toc_chapter_blanks", toc_chapter_blanks, 2);
   pin_change_layparm(i);
   }
@@ -1037,7 +1083,7 @@ if (xref_colour[0] >= 0)
 
 /* If the base typesize value was changed, scale all the vfonts accordingly. */
 
-if (scale_typesize_base != orig_scale_typesize_base)
+if (scale_typesize_base != scale_typesize_base_orig)
   {
   vfontstr *v, **vv, ***vvv;
   for (vvv = &(vfonttables[0]); *vvv != NULL; vvv++)
@@ -1045,8 +1091,8 @@ if (scale_typesize_base != orig_scale_typesize_base)
     for (vv = *vvv; *vv != NULL; vv++)
       {
       v = *vv;
-      v->size = MULDIV(v->size, scale_typesize_base, orig_scale_typesize_base);
-      v->leading = MULDIV(v->leading, scale_typesize_base, orig_scale_typesize_base);
+      v->size = MULDIV(v->size, scale_typesize_base, scale_typesize_base_orig);
+      v->leading = MULDIV(v->leading, scale_typesize_base, scale_typesize_base_orig);
       }
     }
   }
