@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2008, 2011 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 
 /* This module contains functions for reading a source file and parsing it into
@@ -183,7 +183,7 @@ if (*iscdata)
       *t = *pp++;
       if (*t++ == '&')
         {
-        Ustrncpy(t, "amp;", 4);
+        (void)memcpy(t, "amp;", 4);
         t += 4;
         }
       }
@@ -211,8 +211,8 @@ if (Ustrcmp(read_addto->name, "#PCDATA") == 0)
   tbnew->pin_flags = tb->pin_flags | pinflags;
   tbnew->colour = 0;
 
-  memcpy(tbnew->string, tb->string, tb->length);
-  memcpy(tbnew->string + tb->length, pp, len);
+  (void)memcpy(tbnew->string, tb->string, tb->length);
+  (void)memcpy(tbnew->string + tb->length, pp, len);
   tbnew->length = tb->length + len;
   tbnew->string[tbnew->length] = 0;
 
@@ -234,7 +234,7 @@ else
   tbnew->pin_flags = pinflags;
   tbnew->colour = 0;
 
-  memcpy(tbnew->string, pp, len);
+  (void)memcpy(tbnew->string, pp, len);
   tbnew->length = len;
   tbnew->string[tbnew->length] = 0;
 
