@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 /* This module contains the main program and initialization functions. */
 
@@ -450,11 +450,11 @@ if (tn->name[0] == '+')
   uschar *eptr = Ustrrchr(tn->name, ':');
   uschar *vptr = Ustrchr(tn->name, '=');
   if (vptr == NULL)
-    fprintf(stderr, "%.*s in <%s>\n", eptr - tn->name - 1, tn->name + 1,
+    fprintf(stderr, "%.*s in <%s>\n", (int)(eptr - tn->name - 1), tn->name + 1,
       eptr + 1);
   else
-    fprintf(stderr, "%.*s=\"%.*s\" in <%s>\n", vptr - tn->name - 1,
-      tn->name + 1, eptr - vptr - 1, vptr + 1, eptr + 1);
+    fprintf(stderr, "%.*s=\"%.*s\" in <%s>\n", (int)(vptr - tn->name - 1),
+      tn->name + 1, (int)(eptr - vptr - 1), vptr + 1, eptr + 1);
   }
 else
   {
@@ -486,7 +486,7 @@ return TRUE;
 
 
 /*************************************************
-*       Removed ignored elements                 *
+*        Remove ignored elements                 *
 *************************************************/
 
 /* This function is called to remove elements like <sectioninfo> that are
