@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2010, 2011, 2012, 2013 */
+/* Copyright (c) Philip Hazel, 2009, 2010, 2011, 2012, 2013, 2018 */
 
 /* I wrote this because I was frustrated at the lack of free software for
 processing DocBook which could produce really nice typographic PostScript
@@ -12,8 +12,8 @@ output. Much of the text formatting logic is taken from SGCAL. */
 #ifndef INCLUDED_SDOP_H
 #define INCLUDED_SDOP_H
 
-#define SDOP_VERSION "0.80"
-#define SDOP_DATE    "27-November-2013"
+#define SDOP_VERSION "0.81"
+#define SDOP_DATE    "29-August-2018"
 
 /* General header file for all modules */
 
