@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
+/* Copyright (c) Philip Hazel, 2018 */
 
 /* This module contains code for writing the final output file. */
 
@@ -124,7 +124,7 @@ Returns:          TRUE if page is to be output
 */
 
 static BOOL
-okpage(int pagenumber, BOOL isfm)
+okpage(unsigned int pagenumber, BOOL isfm)
 {
 pagelist *pl;
 BOOL odd = (pagenumber & 1) == 1;
@@ -1483,11 +1483,12 @@ for (i = pagestart->next;
 
       if ((tb->pin_flags & PIN_SUPERSCRIPT) != 0)
         {
-        int depth = (tb->pin_flags & (PIN_FNKEYDEF|PIN_FNKEYREF|PIN_FNREFREF))?
-          ol->depth/3
-          :
-          (ol->depth *
-            ((tb->pin_flags >> SSPERCENT_SHIFT) & SSPERCENT_MASK))/100;
+        int depth =
+          (tb->pin_flags & (PIN_FNKEYDEF|PIN_FNKEYREF|PIN_FNREFREF))?
+            ol->depth/3
+            :
+            (ol->depth *
+              (int)((tb->pin_flags >> SSPERCENT_SHIFT) & SSPERCENT_MASK))/100;
         if (insubsuper <= 0) ypos_adjust = depth - insubsuper;
         insubsuper = depth;
         }
@@ -2073,7 +2074,6 @@ preserved and restored also.
 Arguments:
   item_list   the list of items
   pagenumber  the page number
-  ishead      TRUE for head; FALSE for foot
 
 Returns:      nothing
 */
@@ -2083,7 +2083,7 @@ static item hfdummy = { NULL, NULL, &hfdummy, 0, 0,
   { '#','P','D','A','T','A', 0 }, { (paramstr *)(&hfpdata) } };
 
 static void
-write_headfoot(item *item_list, int pagenumber, BOOL ishead)
+write_headfoot(item *item_list, int pagenumber)
 {
 item *i;
 int pcount;
@@ -2352,7 +2352,7 @@ if (page_head_length > 0 && (i->flags & IF_NOHEADFOOT) == 0)
   {
   ypos = ytoppage = page_full_length + margin_bottom;
   DEBUG(D_write) debug_printf("Processing header\n");
-  write_headfoot(hilist, pagenumber, TRUE);
+  write_headfoot(hilist, pagenumber);
   }
 
 DEBUG(D_write) debug_printf("Processing page data\n");
@@ -2378,7 +2378,7 @@ if (page_foot_length > 0 && (i->flags & IF_NOHEADFOOT) == 0)
   {
   ypos = ytoppage = margin_bottom + page_foot_length;
   DEBUG(D_write) debug_printf("Processing footer\n");
-  write_headfoot(filist, pagenumber, FALSE);
+  write_headfoot(filist, pagenumber);
   }
 
 (void)cprintf("\npagesave restore showpage\n%%%%PageTrailer\n\n");
@@ -2447,7 +2447,8 @@ Returns:      TRUE/FALSE
 BOOL
 write_file(uschar *filename)
 {
-int afontnumber, pagenumber, vfontcount;
+int afontnumber, vfontcount;
+unsigned int pagenumber;
 item *i;
 FILE *ph;
 time_t timer;
@@ -2773,7 +2774,7 @@ while (i != NULL && i->next != NULL)
     {
     ypos = ytoppage = page_full_length + margin_bottom;
     DEBUG(D_write) debug_printf("Processing header\n");
-    write_headfoot(toc_head_item_list, pagenumber, TRUE);
+    write_headfoot(toc_head_item_list, pagenumber);
     }
 
   DEBUG(D_write) debug_printf("Processing page data\n");
@@ -2784,7 +2785,7 @@ while (i != NULL && i->next != NULL)
     {
     ypos = ytoppage = margin_bottom + page_foot_length;
     DEBUG(D_write) debug_printf("Processing footer\n");
-    write_headfoot(toc_foot_item_list, pagenumber, FALSE);
+    write_headfoot(toc_foot_item_list, pagenumber);
     }
 
   (void)cprintf("\npagesave restore showpage\n%%%%PageTrailer\n\n");
